@@ -8,7 +8,7 @@ lazy_static! {
     // reduce the number of threads each pool is allowed to half the cpu core count, to avoid rayon
     // hogging cpu
     static ref MAX_RAYON_THREADS: usize =
-            env::var("SAFECOIN_RAYON_THREADS")
+            env::var("SAFEANA_RAYON_THREADS")
                 .map(|x| x.parse().unwrap_or(num_cpus::get() as usize / 2))
                 .unwrap_or(num_cpus::get() as usize / 2);
 }
